      MODULE MAIN1
C***********************************************************************
C     MAIN1
C     ISCST2 Model Data - Array Names, Array Limits, Named Common Blocks
C                         Global Data for All Modules
C
C     MODIFIED - 12/15/93  For New Settling Routines, and Gridded Terrain
C     MODIFIED - 11/8/93   For Wet Deposition Routines
C     MODIFIED - 7/7/93    For Area Sources
C     MODIFIED - 2/15/93   For Revised Deposition Routines
C     MODIFIED - 7/19/94   For OPENPIT Algorithms (JAH/PES)
C     MODIFIED - 7/27/94   Removed ZDM, displacement height, from METVAR
C     MODIFIED - 7/27/94   Added Variable for 10m Reference Wind Speed
C     MODIFIED - 4/17/95   Output CONC/DEPOS/DDEP/WDEP in same model run
C***********************************************************************

      IMPLICIT NONE

C***********************************************************************
C     User Specified Model Parameters for Array Dimensions
C***********************************************************************

CLF90 Most array limits for data storage are now allocated at runtime.
      INTEGER, PARAMETER :: NSEC= 36, NWSCAT= 6, NKST= 6, NHR= 24,
     &                      NPAIR= 100, NWET=2, NHIANN= 10,
     &                      NMXPM= 10

C**   NSRC   = Max Number of Sources
C**   NREC   = Max Number of Receptors
C**   NGRP   = Max Number of Source Groups
C**   NAVE   = Max Number of Short Term Averaging Periods
C**   NVAL   = Max Number of High Values by Receptor (RECTABLE Keyword)
C**   NTYP   = Max Number of Output Types per Run (CONC, DEPOS, DDEP and WDEP)
C**   NMAX   = Max Number of Overall Maximum Values (MAXTABLE Keyword)
C**   NSEC   = Number of Sectors for Building Dimensions
C**   NQF    = Number of Variable Emission Rate Factors Per Source
C**   NPDMAX = Max Number of Particle Diameter Categories Per Source
C**   NWSCAT = Number of Wind Speed Categories
C**   NKST   = Number of Stability Categories
C**   IXM    = Max Number of X-coord (Distance) Values Per Receptor Network
C**   IYM    = Max Number of Y-coord (Direction) Values Per Receptor Network
C**   NNET   = Max Number of Cartesian and/or Polar Receptor Networks
C**   NHR    = Number of Hours in Met Data Loop
C**   NPAIR  = Number of Pairs of TXCONC and IDCONC for TOXXFILE Output
C**   NWET   = Number of phases of precipitation (2 = liquid,frozen)
C**   NHIANN = Number of high period/annual averages to include in
C**                the summary page of the output file (formerly controlled
C**                by NVAL)
C**   NMXPM  = Number of high average H4H 24-hour averages to include
C**                in the summary table for post-1997 PM10 processing


C***********************************************************************
C     Model Constants Specified as Parameters
C***********************************************************************

      REAL, PARAMETER :: PI = 3.141593, TWOPI = 6.283185,
     &                   RTOFPI = 1.772454, SRT2PI = 2.506628,
     &                   BETA = 0.6, G = 9.80616, DTORAD = 0.017453293,
     &                   RTODEG = 57.29578, VK = 0.4,RTPIBY2 = 1.2533141

C**   PI     = PI
C**   TWOPI  = 2.*PI
C**   RTOFPI = SQRT(PI)
C**   SRT2PI = SQRT(2.*PI)
C**   BETA   = Entrainment Coefficient for BLP Rise
C**   G      = Acceleration Due to Gravity (m/s**2)
C**   DTORAD = Degrees to Radians Conversion Factor
C**   RTODEG = Radians to Degrees Conversion Factor
C**   VK     = von-Karman Constant
C**   RTPIBY2= SQRT(PI/2.)


C***********************************************************************
C     Programmer Specified Model Parameters
C***********************************************************************

      INTEGER, PARAMETER :: IFMAX=40, IKN=70, ISTRG=132, IERRN=147,
     &                      ILEN_FLD=80
C*#

C**   IFMAX  = Max Number of Fields Per Runstream Record
C**   IPN    = Number of Pathway IDs (Includes '**')
C**   IKN    = Number of Keywords
C**   ISTRG  = Length of Runstream Image Record
C**   IERRN  = Number of Error/Warning/Informational Messages
C**   ILEN_FLD = Length of Runstream Input Fields.  Also used to
C**              specify length of input filenames and formats.


C***********************************************************************
C     Common Block for Input/Output File Units (Initialized in BLOCK DATA)
C***********************************************************************

      INTEGER ::      INUNIT, IOUNIT, MFUNIT, IERUNT, IERWRT,
     &                IDPUNT, IDPUN2, IRSUNT, IEVUNT, ITEVUT,
     &                IZUNIT, INCUNT

C*----   ISCSTM Modification: allow for hourly emissions - jah 11/3/94                                
     &               ,IHREMI
C*#


C**   INUNIT = Input Runstream File Unit (Initialized to 5)
C**   IOUNIT = Main Printed Output File Unit (Initialized to 6)
C**   MFUNIT = Input Meteorological Data File Unit (Initialized to 19)
C**   IERUNT = Temporary Error/Message File Unit (Initialized to 10)
C**   IERWRT = Permanent Detailed Error/Message File Unit (Init. to 11)
C**   IDPUNT = Main SAVEFILE Unit for Re-start Option (Init. to 12)
C**   IDPUN2 = Secondary SAVEFILE Unit for Re-start Option (Init. to 14)
C**   IRSUNT = INITFILE Unit for Re-start Option (Initialized to 15)
C**   IEVUNT = Event File Unit for Use With ISC2EV Model (Init. to 17)
C**   ITEVUT = Temporary Event File Used to Store High Value Events for
C**            Summary Tables and for EVENTFIL Option (Initialized to 18)
C**   IZUNIT = Gridded Terrain File Used (Initialized to 13)
C**   IHREMI = Hourly Emission Parameters File Unit (Init. to 16)
C**   INCUNT = INCLUDED File Unit (Initialized to 20)

C***********************************************************************
C     This is The Global Variable Definition Block for Runstream Data
C***********************************************************************

      LOGICAL BLINE, INFLD, MARK, ECHO

      CHARACTER PATH*2, PPATH*2, KEYWRD*8, PKEYWD*8, KEYWD*8, KTYPE*5,
     &          RUNST*1

      CHARACTER (LEN=ILEN_FLD) :: FIELD, INPFIL, OUTFIL, INCFIL
      CHARACTER (LEN=ISTRG)    :: RUNST1

      INTEGER ::      LOCB(IFMAX), LOCE(IFMAX), IFC, IDC1, IPNUM, IPPNUM
      DIMENSION       FIELD(IFMAX), KEYWD(IKN), RUNST(ISTRG)


C***********************************************************************
C     This is The Global Variable Definition Block for Error Handling
C***********************************************************************

      LOGICAL FATAL, ISTART, IFINIS, RECERR, ERRLST, EOF

      CHARACTER ERRMSG*50, ERRCOD*3, VERSN*5
      CHARACTER (LEN=ILEN_FLD) :: MSGFIL

      DIMENSION       ERRMSG(IERRN), ERRCOD(IERRN)
      INTEGER ::      ILINE, IERROR, IFTL, IWRN, INFO,
     &                ICLM, IMSG, IHEZ, NFATAL, IPAGE
      REAL ::         EXPLIM
      INTEGER ::      ICSTAT(25), ISSTAT(25), IRSTAT(25), IMSTAT(25),
     &                IOSTAT(25), ITSTAT(25), IESTAT(25)
      INTEGER ::      INCSET, IXYSET, IEVSET, IFGSET


C***********************************************************************
C     This is The Global Variable Definition Block for COntrol Pathway
C***********************************************************************

      LOGICAL DFAULT, CONC, DEPOS, DDEP, WDEP, RURAL, URBAN,
     &        GRDRIS, NOSTD, NOBID, NOCALM, CLMPRO, MSGPRO,
     &        PERIOD, ANNUAL, MONTH, FLAT, ELEV, FLGPOL,
     &        RUN, EVENTS, RSTSAV, RSTINP, DAYTAB, MXFILE, PPFILE,
     &        PLFILE, ANPOST, ANPLOT, STATOK, DEBUG, FSTREC, MULTYR,
     &        TXFILE, DDPLETE, WDPLETE, NOSMPL, NOCMPL, FSTCMP,
     &        EVONLY, SOCONT, DETAIL, NEWMET, SEASONHR, ARDPLETE,
     &        PM10AVE

C*----   ISCSTM Modification: allow for NOCHKD option - jah 11/2/94
     &       ,NOCHKD
C        RWB/MJ - allow for SCIM option - May, 1998.
     &       ,SCIM, WETSCIM, SCIMHR, WETHR, FIRSTWET, TOXICS,
     &        HEGTZI
C*#

      CHARACTER ELTYPE*6, TITLE1*68, TITLE2*68, EVPARM*6, CHRAVE*5,
     &          CHIDEP*4, MODOPS*6, SOELEV*6, REELEV*6, TGELEV*6,
     &          OUTTYP*5

      CHARACTER (LEN=ILEN_FLD) :: SAVFIL, SAVFL2, INIFIL, EVFILE

      INTEGER ::  NHIVAL, NMXVAL, NDUMP

      INTEGER ::  NSRC, NREC, NGRP, NAVE, NVAL, NTYP, NMAX,
     &            NQF, NPDMAX, NNET, IXM, IYM,
     &            NEVE, NUMEVE, IEVENT

      INTEGER, ALLOCATABLE :: KAVE(:)

     
      ALLOCATABLE ::  CHRAVE(:), CHIDEP(:,:), OUTTYP(:)
      DIMENSION       MODOPS(19)



C***********************************************************************
C     This is The Global Variable Definition Block for SOurce Pathway
C***********************************************************************

      CHARACTER SRCID*8, SRCTYP*8, SOPCRD*1, SOGAS*1, GRPID*8,
     &          EMILBL*40, OUTLBL*40, POLLUT*8, PSOID*8, QFLAG*6,
     &          PERLBL*40

C*----   ISCSTM Modification: allow for hourly emissions - jah 11/3/94
      CHARACTER (LEN=ILEN_FLD) :: HRFILE
C*#
      CHARACTER PREVGRPID*8
     
      LOGICAL LDPART, LWPART, LDGAS, LWGAS

      REAL, ALLOCATABLE ::    AXS(:), AYS(:), AZS(:), AQS(:),
     &                        AHS(:), ATS(:), AVS(:), ADS(:),
     &                        ASYINI(:), ASZINI(:)
      REAL, ALLOCATABLE ::    ADSBH(:,:), ADSBW(:,:)
      INTEGER, ALLOCATABLE :: IDSWAK(:,:), INPD(:)
      REAL, ALLOCATABLE ::    QFACT(:,:)
      REAL ::         EMICON, HAFLIF, DECOEF, VAIRMS, ZRDEP, VDPHOR
      REAL, ALLOCATABLE ::    EMIFAC(:), APDIAM(:,:), APHI(:,:),
     &                        APDENS(:,:), ASC(:,:),
     &                        AVGRAV(:,:), ATSTOP(:,:),
     &                        APSLIQ(:,:), APSICE(:,:),
     &                        AGSCAV(:,:)
     &

C*----   ISCSTM Modification: allow for hourly emissions - jah 11/3/94
      REAL ::     HRQS, HRTS, HRVS
      REAL, ALLOCATABLE ::  EV_HRQS(:,:), EV_HRTS(:,:), EV_HRVS(:,:)
      INTEGER ::  KURHRQ
C*----     
C*#

      INTEGER, ALLOCATABLE :: IGROUP(:,:)
      ALLOCATABLE ::  SRCID(:), SRCTYP(:), SOPCRD(:),
     &                SOGAS(:),
     &                GRPID(:), QFLAG(:), EMILBL(:),
     &                OUTLBL(:),
     &                PERLBL(:)


C**   KURHRQ  Date/Time Stamp for Hourly Emissions Data
C**   HRFILE  Hourly Emissions Data File Name          
C*#

C***********************************************************************
C     This is The Global Variable Definition Block for the New Area
C     Source Algorithm - 7/7/93
C
C*    Added XVERT,YVERT - Jayant Hardikar, PES, 7/20/94
C***********************************************************************

      INTEGER, PARAMETER :: NVMAX = 24, NVMAX2 = NVMAX*2

C**   NVMAX = Maximum Number of Vertices in a Single Area Source + 4
C**   NVMAX2= NVMAX * 2
C**   Note that the '+ 4' added to number of vertices for NVMAX refers
C**   to the maximum number of sides on an AREAPOLY source that a
C**   straight line can intersect.  For complex shapes, '+ 4' may not
C**   by large enough.  R. Brode, PES, Inc.

      LOGICAL LSEG

      INTEGER ::      IVERT, NVERT, NSEGS
     &
      REAL ::         UVERT(NVMAX), VVERT(NVMAX), VNVERT(NVMAX),
     &                WVERT(NVMAX), UASEGS(NVMAX), UBSEGS(NVMAX),
     &                XVERT(NVMAX), YVERT(NVMAX)
      REAL ::         SPA(NVMAX,2)
      REAL, ALLOCATABLE :: AXINIT(:), AYINIT(:), AANGLE(:),
     &                     AXVERT(:,:), AYVERT(:,:),
     &                     RADIUS(:), AXCNTR(:), AYCNTR(:)
      INTEGER, ALLOCATABLE :: NVERTS(:)



C***********************************************************************
C     This is The Global Variable Definition Block for the New OPENPIT
C     Source Algorithm - 7/19/94
C***********************************************************************

      REAL, PARAMETER   :: ALPHA = 0.029
      REAL, ALLOCATABLE :: AALPHA(:), APDEFF(:), AVOLUM(:)
      REAL, ALLOCATABLE :: EFRAC(:), QPART(:)
      REAL ::  PALPHA, THETA, PDEFF, PDREL, PITFRA, QEFF
      REAL ::  PITLEN, PITWID, PITL, EMIHGT, XEFF, YEFF

      
C*    ALPHA     = Proportionality Constant for determining Escape Fraction
C*    AALPHA    = Array of Angles of Long Pit Dimension w.r.t. 
C*                North for Each Source
C*    PALPHA    = Angle of Long Pit Dimension w.r.t. North for
C*                the Current Source
C*    THETA     = Wind Direction angle w.r.t Long Axis
C*                of the Pit
C*    APDEFF    = Array of Effective Pit Depths for Each Source
C*    PDEFF     = Effective Pit Depths for Current Source
C*    PDREL     = Relative Pit Depth
C*    AVOLUM    = Array of Volume of the OPENPIT Sources
C*    EFRAC     = Array of Escape Fractions
C*    QPART     = Array of Adjusted Emission Rates 
C*    PITFRA    = Fractional Size of the Effective Pit Area
C*    PITLEN    = Length of the Pit
C*    PITWID    = Width of the Pit
C*    PITL      = Along-Wind Length of the Pit
C*    EMIHGT    = Height of Emissions Above Base of Pit
C*    XEFF      = X-dimension of Effective Pit
C*    YEFF      = Y-dimension of Effective Pit

      
      
c----------------------------------------------------------------------
c --- COMMON BLOCK /DRYGAS/ -- Dry deposition parameters        CALPUFF
c----------------------------------------------------------------------
c
      REAL, ALLOCATABLE :: pdiff(:),alphas(:),react(:),
     1 rm(:),henry(:),rgg(:),rgw1(:),rcut(:),
     2 rd1(:)
      REAL :: rcutr,rgr,reactr,pconst,bmin,bmax,qswmax,dconst1,
     1 dconst2,dconst3,
     2 qsw,xlai,vdepg,uservd
CLF90      REAL ::       pdiff(NSRC),alphas(NSRC),react(NSRC),
CLF90     1 rm(NSRC),henry(NSRC),rgg(NSRC),rgw1(NSRC),rcut(NSRC),
CLF90     2 rd1(NSRC),rcutr,rgr,reactr,pconst,bmin,bmax,qswmax,dconst1,
CLF90     3 dconst2,dconst3,
CLF90     4 qsw,xlai,vdepg,uservd

      CHARACTER*40  REFSPE

      LOGICAL  UNSTRESSED, STRESSED, INACTIVE, LUSERVD
C
C     REFSPE      - Reference Species (Default is SO2)
C     UNSTRESSED  - Logical for state of unirrigated vegetation
C     STRESSED    - Logical for state of unirrigated vegetation
C     INACTIVE    - Logical for state of unirrigated vegetation
c
c --- COMMON BLOCK /DRYGAS/ Variables:
c       PDIFF(NSRC) - real    - Molecular diffusivity (m**2/s)
c                               of each pollutant.
c                               SEE NOTE #1
c      ALPHAS(NSRC) - real    - Solubility enhancement factor due
c                               to the aqueous phase reactivity of
c                               the pollutant.
c       REACT(NSRC) - real    - Reactivity factor for each
c                               pollutant.
c          RM(NSRC) - real    - Mesophyll resistance (s/m)
c                               SEE NOTE #2
c       HENRY(NSRC) - real    - Henry's law constant (ratio of
c                               gas to aqueous phase concentration
c                               of the pollutant).
c         RGG(NSRC) - real    - Resistance (s/m) to direct
c                               transfer of the pollutant to the
c                               ground.
c        RGW1(NSRC) - real    - Ratio of HENRY(i)/(ALPHAS(i)*d3)
c                               where d3 is a constant.  Used in
c                               computing resistance directly to
c                               water surface.
c        RCUT(NSRC) - real    - Cuticle resistance (s/m).
c         RD1(NSRC) - real    - Ratio d1*SC**d2/k, where d1,d2 are
c                               constants, SC is the Schmidt
c                               number, and k is the von Karman
c                               constant
c             RCUTR - real    - Reference cuticle resistance (s/m)
c                               SEE NOTE #2
c               RGR - real    - Reference ground resistance (s/m)
c                               SEE NOTE #2
c            REACTR - real    - Reference pollutant reactivity
c            PCONST - real    - Stomatal constant (m**2)
c              BMIN - real    - Minimum width of the stomatal
c                               opening (m)
c              BMAX - real    - Maximum width of the stomatal
c                               opening (m)
c            QSWMAX - real    - Short-wave solar radiation (W/m**2)
c                               level at which full opening of the
c                               stomata occurs
c   DCONST1,DCONST2 - real    - Empirical constants in deposition
c                               layer resistance equation
c           DCONST3 - real    - Constant in the "ground" resistance
c                               to water surfaces
c
c  NOTE #1: Input units of this variable are cm**2/s.  Conversion to m**2/s
c           is made internally in the SETUP phase.
c
c  NOTE #2: Input units of s/cm are converted to s/m in the SETUP phase.


      
C***********************************************************************
C     This is The Global Variable Definition Block for REceptor Pathway
C***********************************************************************

      LOGICAL ISTA, IEND, NEWID

      CHARACTER NETID*8, NETIDT*8, PNETID*8, NTID*8, NTTYP*8,
     &          RECTYP*2, PXSOID*8, PESOID*8

      REAL, ALLOCATABLE ::    AXR(:), AYR(:), AZELEV(:),
     &                        AZFLAG(:)
      INTEGER, ALLOCATABLE :: IREF(:)
      ALLOCATABLE ::          NETID(:), RECTYP(:), NTID(:),
     &                        NTTYP(:)
      INTEGER ::      ICOUNT, JCOUNT, IZE, IZF, IRZE, IRZF, IRXR, IRYR,
     &                IBND, IBELEV, INNET
      REAL ::         XINT, YINT
      REAL, ALLOCATABLE ::    XCOORD(:,:), YCOORD(:,:),
     &                        XORIG(:), YORIG(:)
      INTEGER, ALLOCATABLE :: NETSTA(:), NETEND(:),
     &                        NUMXPT(:), NUMYPT(:)



C***********************************************************************
C     This is The Global Variable Definition Block for MEteorology Pathway
C***********************************************************************

      CHARACTER SFNAME*40, UANAME*40

      CHARACTER (LEN=ILEN_FLD) :: METFRM, METINP, SCIMFIL
      LOGICAL SCIMOUT

      INTEGER ::      ISDATE, IEDATE, ISYR, ISMN, ISDY, ISHR, IEYR,
     &                IEMN, IEDY, IEHR, IPROC(366),
     &                ISYEAR, IUYEAR, IDSURF,
     &                IDUAIR, ISJDAY, IEJDAY,
     &                NDAYS, INCRST,
     &                ISTRT_CENT, ISTRT_WIND
C        RWB/MJ - allow for SCIM option - May, 1998.
     &               ,NREGSTART, NREGINT, IFIRSTHR, ISUNIT
     &               ,NSKIPTOT, NSKIPWET, NSKIPDRY
     &               ,NSWETCLM, NSDRYCLM, NSWETMSG, NSDRYMSG
     &               ,NWETHR, NWETINT, NWETSTART

      REAL ::         PUSER(NKST,NWSCAT), DTUSER(NKST,NWSCAT),
     &                PURB(NKST), PRUR(NKST), DTURB(NKST), DTRUR(NKST),
     &                UCAT(5), ZREF, ROTANG, UMIN,
     &                VIRTPNT_URB(NKST), VIRTPNT_RUR(NKST), VP_FACT


C***********************************************************************
C     This is The Global Variable Definition Block for METEXT
C***********************************************************************

      LOGICAL CLMHR, MSGHR, UNSTAB, NEUTRL, STABLE,
     &        RUNERR, NEWDAY, ENDMON, USERP, USERDT

      INTEGER ::      KSTMSG
      INTEGER ::      IHOUR, IYEAR, IMONTH, IDAY, KURDAT, JDAY, ISEAS,
     &                IPHOUR, IPDATE, IPCODE, KST,
     &                IYR, IDAY_OF_WEEK
      INTEGER ::      FULLDATE
      REAL ::         AFV, UREF, TA, ZI, ZIRUR, ZIURB,
     &                AFVLST, AFV24, S, RTOFS,
     &                USTAR, EL, Z0M, PRATE, UREF10

      INTEGER :: IKST(NHR), IAPCODE(NHR)
      REAL :: AUREF(NHR), ATA(NHR), AAFV(NHR), AAFVR(NHR), AZI(2,NHR)
      REAL :: APROF(NHR), ADTDZ(NHR), AUSTAR(NHR), AEL(NHR), AZ0M(NHR),
     &        APRATE(NHR), AQSW(NHR), AXLAI(NHR)

      INTEGER :: IENDHOUR, IENDDY, IENDMN, NUMYRS, NREMAIN

C***********************************************************************
C     This is The Global Variable Definition Block for Terrain Grid Pathway
C***********************************************************************

      CHARACTER (LEN=ILEN_FLD) :: TERINP
      LOGICAL LTGRID

      REAL ::     TGX0, TGY0, GRDXLL, GRDXUR, GRDYLL, GRDYUR, XYINT


C***********************************************************************
C     This is The Global Variable Definition Block for Calculation
C***********************************************************************

      LOGICAL CALCS, WAKE, WAKESS, WAKLOW, BUOYNT, TALL, SQUAT, SSQUAT

      INTEGER ::      IREC,   ISRC,   IGRP,   IAVE,   ITYP,  ISET,
     &                NUMREC, NUMSRC, NUMGRP, NUMAVE, NUMTYP,
     &                NUMYR, ICYEAR, NPD, IFVSEC, IUCAT
      REAL ::         XS, YS, ZS, QS, HS, DS, VS, TS, SYINIT,
     &                SZINIT, XINIT, YINIT, ANGLE, XCNTR, YCNTR,
     &                DSBH, DSBW, D, VD, E, WDRAD, WDSIN, WDCOS
      REAL, ALLOCATABLE :: V(:)
C                        Accomodate Wet SCIM'ing, M. Jindal, PES, 6/10/98
     &                    ,VDRY(:)
      REAL, ALLOCATABLE :: PDIAM(:), PHI(:), PDENS(:),
     &                     SC(:), VGRAV(:), TSTOP(:),
     &                     VDEP(:),
     &                     WQCOR(:), WQCORC(:),
     &                     SZCOR(:), SZCORC(:), SZMIN(:),
     &                     DQCOR(:), PCORZR(:), PCORZD(:),
     &                     DQCORC(:), PCORZRC(:), PCORZDC(:),
     &                     PSCAV(:,:), GSCAV(:),
     &                     PSCVRT(:)
      REAL ::         SZCORG, SZCORGC, WQCORG, WQCORGC, GSCVRT,
     &                DQCORG, PCORZRG, PCORZDG,
     &                DQCORGC, PCORZRGC, PCORZDGC
      REAL ::         XR, YR, X, Y, ZELEV, ZFLAG, DISTR
      REAL ::         HE, HSP, HEFLAT, HTER, HEMWAK, ZB, ZM,
     &                XY, XZ, SBID, FM, FB, DTDZ, DHF, DHP, DELT,
     &                DHPB, DHPM, XF, XFM, XFB, XRAD
      REAL ::         US, SY, SZ, DA, ZLY, ZLB, X3LB, RINIT,
     &                CB, CM, QTK, P


C***********************************************************************
C     This is The Global Variable Definition Block for Complex Terrain
C***********************************************************************

      LOGICAL SIMPLE, INTERM, COMPLX

      REAL ::         TCF(NKST), ZMIN, HECMP1, HECOMP, HESETL,
     &                CORR, DELTHP, XZCMP1, SZCMP1, SBCMP1,
     &                DHPCMP, DHFCMP,
     &                SIMCON, COMCON


C***********************************************************************
C     This is The Global Variable Definition Block for EVent Pathway
C***********************************************************************

      CHARACTER EVNAME*8, EVGRP*8
      INTEGER, ALLOCATABLE ::  EVAPER(:), EVDATE(:), EVJDAY(:),
     &                         IDXEV(:)

      ALLOCATABLE ::  EVNAME(:), EVGRP(:)




C***********************************************************************
C     This is The Global Variable Definition Block for OUtput Pathway
C***********************************************************************

      CHARACTER (LEN=ILEN_FLD) :: THRFIL, PSTFIL, PLTFIL, ANNPST,
     &                            ANNPLT, THRFRM, PSTFRM, PLTFRM,
     &                            TOXFIL, SEAHRS

      INTEGER, ALLOCATABLE :: NHIAVE(:,:), MAXAVE(:), IMXVAL(:),
     &                        IDYTAB(:), MAXFLE(:,:),
     &                        IPSTFL(:,:), IPLTFL(:,:,:),
     &                        IANPST(:), IANPLT(:), INHI(:),
     &                        ITOXFL(:), ISEAHR(:)
      REAL, ALLOCATABLE ::    THRESH(:,:), TOXTHR(:)
      INTEGER, ALLOCATABLE :: IMXUNT(:,:), IPSUNT(:,:),
     &                        IPSFRM(:,:), IPLUNT(:,:,:),
     &                        IAPUNT(:), IANFRM(:), IPPUNT(:),
     &                        ITXUNT(:), ISHUNT(:)

      ALLOCATABLE ::  THRFIL(:,:), PSTFIL(:,:),
     &                PLTFIL(:,:,:), ANNPST(:),
     &                ANNPLT(:), TOXFIL(:), SEAHRS(:)

      INTEGER, ALLOCATABLE :: IDCONC(:,:)

      INTEGER ::      ITAB, NXTOX, NYTOX, NHOURS, IPAIR

      REAL, ALLOCATABLE ::    TXCONC(:,:)



C***********************************************************************
C     This is The Global Variable Definition Block for Working Space
C***********************************************************************

      CHARACTER WORKID*8, DUMMY*8

      INTEGER     :: IMIT, INUM, IDUM, INDAVE, INDGRP, INDVAL,
     &               ISC, IOERRN, NCPP, NRPP, NGPP, NPPX, NPPY
      REAL        :: FNUM, RNUM

      ALLOCATABLE ::          WORKID(:)
      INTEGER, ALLOCATABLE :: IWRK2(:,:)

C     Declare Temporary Work Arrays for ZELEV and ZFLAG Receptor Data
      REAL, ALLOCATABLE :: ZETMP1(:), ZETMP2(:)
      REAL, ALLOCATABLE :: ZFTMP1(:), ZFTMP2(:)


      SAVE

C***********************************************************************
C     Formerly MAIN3.INC
C     ISCST2 Model Data - Array Names, Array Limits, Named Common Blocks
C                         Necessary for Model Results
C     MODIFIED - 4/17/95   Output CONC/DEPOS in same model run
C***********************************************************************


C***********************************************************************
C     This is The Global Variable Definition Block For The Maximum
C     Value, Highest Value, Average Value, Annual Average Value and
C     Model Result Arrays.  Also Included are Calm/Missing Flag Arrays.
C***********************************************************************


      CHARACTER HCLMSG, MCLMSG, HMCLM

      REAL,    ALLOCATABLE ::  HRVAL(:), SIMPL(:), COMPL(:),
     &                         AVEVAL(:,:,:,:)
C                             Accomodate Wet SCIM'ing, M. Jindal, PES, 6/10/98
     &                        ,HRVALD(:),HRVALJD(:,:)
     &                        ,SIMPLD(:),SIMPLJD(:,:)
     &                        ,COMPLD(:),COMPLJD(:,:)
      REAL,    ALLOCATABLE ::  HIVALU(:,:,:,:,:),
     &                         HMAX(:,:,:,:)
      INTEGER, ALLOCATABLE ::  HMLOC(:,:,:,:),
     &                         HMDATE(:,:,:,:),
     &                         NHIDAT(:,:,:,:,:)

      REAL,    ALLOCATABLE ::  ANNVAL(:,:,:), AMXVAL(:,:,:),
     &                         SHVALS(:,:,:,:,:)
C                             Accomodate Wet SCIM'ing, M. Jindal, PES, 6/10/98
     &                        ,ANNVALD(:,:,:), ANNVALW(:,:,:)
     &                        ,ANNVALJD(:,:,:,:), ANNVALJW(:,:,:,:)
      INTEGER, ALLOCATABLE ::  IMXLOC(:,:,:)
      INTEGER              ::  IANHRS, IANCLM, IANMSG,
     &                         NSEAHR(4,24), NSEACM(4,24)
C                             Accomodate Wet SCIM'ing, M. Jindal, PES, 6/10/98
     &                        ,IANWET, IWETCLM, IWETMSG
      REAL,    ALLOCATABLE ::  RMXVAL(:,:,:,:)
      INTEGER, ALLOCATABLE ::  MXDATE(:,:,:,:),
     &                         MXLOCA(:,:,:,:)
      INTEGER, ALLOCATABLE ::  NUMHRS(:), NUMCLM(:), NUMMSG(:)
      ALLOCATABLE ::           HCLMSG(:,:,:,:,:),
     &                         MCLMSG(:,:,:,:),
     &                         HMCLM(:,:,:,:)

      REAL,    ALLOCATABLE ::  SUMANN(:,:,:)
      REAL,    ALLOCATABLE ::  SUMH4H(:,:), MXPMVAL(:,:)
      INTEGER, ALLOCATABLE ::  MXPMLOC(:,:)


C***********************************************************************
C     This is The Global Variable Definition Block For The
C     EVENT Model Result Arrays
C***********************************************************************

      REAL, ALLOCATABLE ::  EV_AVEVAL(:), HRVALS(:,:), GRPVAL(:)

      REAL ::  GRPAVE
      INTEGER ::  EV_NUMHRS, EV_NUMCLM, EV_NUMMSG, ISTAHR, IENDHR


C***********************************************************************
C
C     BLOCK DATA SUBPROGRAM OF THE ISC - Version 2 MODEL
C
C     PURPOSE: Initialize Data in COMMON Blocks
C
C     MODIFIED:  To Include Terrain Grid pathway - 12/15/93
C
C     MODIFIED:  To Include WET DEPOSITION Arrays - 11/8/93
C
C     MODIFIED:  To Include New Area Source Arrays - 7/7/93
C
C     MODIFIED:  For revised DRY DEPOSITION code - 2/15/93
C
C     MODIFIED:  To Include TOXXFILE Option - 9/29/92
C
C***********************************************************************

C     Variable Declarations


C***********************************************************************
C     Initialize Model Version Number, VERSN (Year, Julian Day), as a
C     Character Variable
C***********************************************************************

      DATA VERSN /'00259'/


C***********************************************************************
C     Input/Output File Units and Input/Output File Names
C***********************************************************************

CLF95 Change INUNIT from 5 to 7, and IOUNIT from 6 to 8, for the
CLF95 Lahey LF95 compiler (version 5.0).
      DATA INUNIT/ 7/, IOUNIT/ 8/, MFUNIT/19/, IERUNT/10/,
     &     IERWRT/11/, IDPUNT/12/, IDPUN2/14/, IRSUNT/15/,     
     &     IEVUNT/17/, ITEVUT/18/, IZUNIT/13/,
     &     IHREMI/16/, INCUNT/20/, ISUNIT/ 9/
C*#
      DATA INPFIL/' '/, OUTFIL/' '/


C***********************************************************************
C     Initialize Keyword Array
C***********************************************************************

      INTEGER, PRIVATE :: I

      DATA (KEYWD(I),I=1,IKN) /'STARTING','FINISHED','TITLEONE',
     &   'TITLETWO','MODELOPT','AVERTIME','POLLUTID','HALFLIFE',
     &   'DCAYCOEF','TERRHGTS','ELEVUNIT','FLAGPOLE','RUNORNOT',
     &   'EVENTFIL','SAVEFILE','INITFILE','MULTYEAR','ERRORFIL',
     &   'GASDEPRF','VEGSTATE','GASDEPVD','EVENTFIL',
     &   'LOCATION','SRCPARAM','BUILDHGT','BUILDWID','LOWBOUND',
     &   'EMISFACT','EMISUNIT','PARTDIAM','MASSFRAX','PARTDENS',
     &   'PARTSLIQ','PARTSICE','GAS-SCAV','CONCUNIT','DEPOUNIT',
     &   'HOUREMIS','GASDEPOS','EVENTPER','EVENTLOC',
     &   'SRCGROUP','GRIDCART','GRIDPOLR','DISCCART','DISCPOLR',
     &   'BOUNDARY','BOUNDELV','INPUTFIL','ANEMHGHT','SURFDATA',
     &   'UAIRDATA','STARTEND','DAYRANGE','WDROTATE','WINDPROF',
     &   'DTHETADZ','WINDCATS','RECTABLE','MAXTABLE','DAYTABLE',
     &   'MAXIFILE','POSTFILE','PLOTFILE','TOXXFILE','EVENTOUT',
     &   'INCLUDED','SCIMBYHR','SEASONHR','AREAVERT'/


C***********************************************************************
C     Initialize Miscellaneous Variables
C***********************************************************************

      DATA IPROC /366*1/, EXPLIM /-50.0/
      DATA UCAT /1.54, 3.09, 5.14, 8.23, 10.8/
      DATA MODOPS /19*'      '/


C***********************************************************************
C     Initialize Default Wind Profile Exponents and DTHETADZ
C***********************************************************************

C     STAB. CLASS         A    B     C     D      E      F
C                        ***  ***   ***   ***    ***    ***
      DATA DTURB         /0.,  0.,   0.,   0.,   0.02, 0.035/,
     &     DTRUR         /0.,  0.,   0.,   0.,   0.02, 0.035/,
     &     PURB         /0.15, 0.15, 0.20, 0.25, 0.30, 0.30/,
     &     PRUR         /0.07, 0.07, 0.10, 0.15, 0.35, 0.55/,
     &     VIRTPNT_URB  /3.5,  3.5,  5.5,  10.5, 15.5, 15.5/,
     &     VIRTPNT_RUR  /3.5,  5.5,  7.5,  12.5, 15.5, 25.5/


C***********************************************************************
C     Initialize Setup Status Arrays
C***********************************************************************

      DATA ICSTAT/25*0/, ISSTAT/25*0/, IRSTAT/25*0/, IMSTAT/25*0/,
     &     IOSTAT/25*0/, ITSTAT/25*0/


c
c --- DRYGAS common block
      data rcutr/30.0/,rgr/10.0/,reactr/8.0/
      data pconst/2.3e-8/,bmax/2.5e-6/,bmin/0.1e-6/,qswmax/600./
      data dconst1/2.0/,dconst2/0.6666667/,dconst3/4.8e-4/

C***********************************************************************
C     Initialize Error Code and Message Arrays
C***********************************************************************

      DATA ERRCOD(1)/'100'/,
     &  ERRMSG(1)/'Ruta Especificada Invlida. Ruta Con Problema es  '/
      DATA ERRCOD(2)/'105'/,
     &  ERRMSG(2)/'Clave Especificada Invalida. Clave con Problema es'/
      DATA ERRCOD(3)/'110'/,
     &  ERRMSG(3)/'Clave No Vlida Para Esta Ruta.  La Clave es      '/
      DATA ERRCOD(4)/'115'/,
     &  ERRMSG(4)/'STARTING o FINISHED Fuera de Secuencia: Ruta =    '/
      DATA ERRCOD(5)/'120'/,
     &  ERRMSG(5)/'Ruta Fuera de Secuencia: Ruta =                   '/
      DATA ERRCOD(6)/'125'/,
     &  ERRMSG(6)/'Flujo de FINISHED Faltante Arch.Incompleto: ISTAT='/
      DATA ERRCOD(7)/'130'/,
     &  ERRMSG(7)/'Clave Mandatoria Faltante.  La Clave Faltante es  '/
      DATA ERRCOD(8)/'135'/,
     &  ERRMSG(8)/'Duplicacin de Clave No Repetible: Clave =        '/
      DATA ERRCOD(9)/'140'/,
     &  ERRMSG(9)/'Orden de Claves Invlido. La Clave Problemtica es'/
      DATA ERRCOD(10)/'145'/,
     &  ERRMSG(10)/'Opciones en Conflicto: MULTYEAR y Re-Inicio       '/
      DATA ERRCOD(11)/'150'/,
     &  ERRMSG(11)/'Opciones en Conflicto: MULTYEAR y Contam. Incorrec'/
      DATA ERRCOD(12)/'155'/,
     &  ERRMSG(12)/'Clave de Decaimiento en Confl.Entradas Ignoradas  '/
      DATA ERRCOD(13)/'160'/,
     &  ERRMSG(13)/'Clave Secundaria. ORIG Duplicada para  GRIDPOLR:  '/
      DATA ERRCOD(14)/'170'/,
     &  ERRMSG(14)/'Clave Secundaria Invlida Para Cuadric. de Recept.'/
      DATA ERRCOD(15)/'175'/,
     &  ERRMSG(15)/'Clave Sec. Faltante END Para Cuadric. de Receptor '/
      DATA ERRCOD(16)/'180'/,
     &  ERRMSG(16)/'Clave Sec. Para Cuadric. de Receptor en Conflicto '/
      DATA ERRCOD(17)/'185'/,
     &  ERRMSG(17)/'Faltan Claves Para Recept. Recept. Sin Especificar'/
      DATA ERRCOD(18)/'190'/,
     &  ERRMSG(18)/'Sin Claves Para Ruta OU y Sin Proms. PERIOD/ANNUAL'/
      DATA ERRCOD(19)/'195'/,
     &  ERRMSG(19)/'Opcin Incompatible Con SAVEFILE o INITFILE       '/
      DATA ERRCOD(20)/'200'/,
     &  ERRMSG(20)/'Parmetro(s) Faltantes. Opciones Sin Especif. Para'/
      DATA ERRCOD(21)/'201'/,
     &  ERRMSG(21)/'Insuficientes Parmetros Para la Clave de         '/
      DATA ERRCOD(22)/'202'/,
     &  ERRMSG(22)/'Demasiados Parmetros Para la Clave de            '/
      DATA ERRCOD(23)/'203'/,
     &  ERRMSG(23)/'Parmetro Invlido.  El Problema est en          '/
      DATA ERRCOD(24)/'204'/,
     &  ERRMSG(24)/'Parmetros  Optativos en Conflicto. Por Omisin:  '/
      DATA ERRCOD(25)/'205'/,
     &  ERRMSG(25)/'Parmetros Optativos Sin Indicar. Por Omisin:    '/
      DATA ERRCOD(26)/'206'/,
     &  ERRMSG(26)/'DFAULT Forzosa Sobreescribe Opcin No-DFAULT en   '/
      DATA ERRCOD(27)/'207'/,
     &  ERRMSG(27)/'Parmetros Sin Espec. Se Usarn Valore Por Omisin'/
      DATA ERRCOD(28)/'208'/,
     &  ERRMSG(28)/'Se Encontr Campo Numrico Ilegal en              '/
      DATA ERRCOD(29)/'209'/,
     &  ERRMSG(29)/'Variable Negativa Aparece En Variable No-Negativa '/
      DATA ERRCOD(30)/'210'/,
     &  ERRMSG(30)/'Nmero de Prom. de Corto Plazo Excede Max:  NAVE= '/
      DATA ERRCOD(31)/'211'/,
     &  ERRMSG(31)/'Duplicacin de Perodo de Promediacin Para Clave '/
      DATA ERRCOD(32)/'212'/,
     &  ERRMSG(32)/'Se Encotr END Sin Puntos (X,Y) Bien Definidos    '/
      DATA ERRCOD(33)/'213'/,
     &  ERRMSG(33)/'ELEV Inconsistente Con Opcin: Entradas Ignoradas '/
      DATA ERRCOD(34)/'214'/,
     &  ERRMSG(34)/'ELEV Inconsistente Con Opcin: Valores Por Omisin'/
      DATA ERRCOD(35)/'215'/,
     &  ERRMSG(35)/'FLAG Inconsistente Con Opcin: Entradas Ignoradas '/
      DATA ERRCOD(36)/'216'/,
     &  ERRMSG(36)/'FLAG Inconsistente Con Opcin: Valores Por Omisin'/
      DATA ERRCOD(37)/'217'/,
     &  ERRMSG(37)/'Ms De Un Delimitador En Un Campo Para Clave      '/
      DATA ERRCOD(38)/'218'/,
     &  ERRMSG(38)/'Nmero de Puntos (X,Y) No Correspon. Con Nmero de'/
      DATA ERRCOD(39)/'219'/,
     &  ERRMSG(39)/'Nmero de Receptores Especif. Excede Mx: NREC=   '/
      DATA ERRCOD(40)/'220'/,
     &  ERRMSG(40)/'Origen Faltante (Por Omisin = 0,0) En GRIDPOLR   '/
      DATA ERRCOD(41)/'221'/,
     &  ERRMSG(41)/'Falta Especificar Distancia En Red Polar          '/
      DATA ERRCOD(42)/'222'/,
     &  ERRMSG(42)/'En Red Polar Falta Distancia o Grados             '/
      DATA ERRCOD(43)/'223'/,
     &  ERRMSG(43)/'Falta Campo de Distancia o Grados en              '/
      DATA ERRCOD(44)/'224'/,
     &  ERRMSG(44)/'Nmero de Redes de Receptor Excede Mx: NNET =    '/
      DATA ERRCOD(45)/'225'/,
     &  ERRMSG(45)/'El Nmero de Coordenadas-X Excede Mx:   IXM =    '/
      DATA ERRCOD(46)/'226'/,
     &  ERRMSG(46)/'El Nmero de Coordenadas-Y Excede Mx:   IYM =    '/
      DATA ERRCOD(47)/'227'/,
     &  ERRMSG(47)/'No Se Definieron Receptores En La Ruta RE.        '/
      DATA ERRCOD(48)/'228'/,
     &  ERRMSG(48)/'Valores Por Omisin Para Parmetro(s) en Clave    '/
      DATA ERRCOD(49)/'229'/,
     &  ERRMSG(49)/'Demasiados Parmetros-Se Ignoran Entradas en Clave'/
      DATA ERRCOD(50)/'230'/,
     &  ERRMSG(50)/'Insuficientes Valores Numricos Para              '/
      DATA ERRCOD(51)/'231'/,
     &  ERRMSG(51)/'Demasiados Valores Numricos Para                 '/
      DATA ERRCOD(52)/'232'/,
     &  ERRMSG(52)/'Nmero de Fuentes Excede Mximo:           NSRC = '/
      DATA ERRCOD(53)/'233'/,
     &  ERRMSG(53)/'Dimensiones de Edificio Para Fuente No Puntual    '/
      DATA ERRCOD(54)/'234'/,
     &  ERRMSG(54)/'Demasiados Sectores Para                          '/
      DATA ERRCOD(55)/'235'/,
     &  ERRMSG(55)/'Nmero de Grupos de Fuente Excede Mximo   NGRP = '/
      DATA ERRCOD(56)/'236'/,
     &  ERRMSG(56)/'Insuficientes BUILDHGTs Para SourceID             '/
      DATA ERRCOD(57)/'237'/,
     &  ERRMSG(57)/'Insuficientes BUILDWIDs Para SourceID             '/
      DATA ERRCOD(58)/'238'/,
     &  ERRMSG(58)/'Insuficientes LOWBOUNDs Para SourceID             '/
      DATA ERRCOD(59)/'239'/,
     &  ERRMSG(59)/'Insuficientes QFACTs Para SourceID                '/
      DATA ERRCOD(60)/'240'/,
     &  ERRMSG(60)/'Nmero Incons de Categs de Asentam/Remocin para  '/
      DATA ERRCOD(61)/'242'/,
     &  ERRMSG(61)/'Categ de Tamao de Partculas Sin Indicar En SRCID'/
      DATA ERRCOD(62)/'244'/,
     &  ERRMSG(62)/'Demasiadas Categ de Tamao Indicadas Para         '/
      DATA ERRCOD(63)/'245'/,
     &  ERRMSG(63)/'No. de Categ Asentam/Remocin Excede Max:  NPDMAX='/
      DATA ERRCOD(64)/'248'/,
     &  ERRMSG(64)/'No Se Definieron Fuentes En Ruta SO.              '/
      DATA ERRCOD(65)/'250'/,
     &  ERRMSG(65)/'XPNT/DIST o YPNT/DIR Duplicadas Para  GRID        '/
      DATA ERRCOD(66)/'252'/,
     &  ERRMSG(66)/'ID de Red de Receptores Duplicada.        NETID = '/
      DATA ERRCOD(67)/'255'/,
     &  ERRMSG(67)/'Distancias de Lmite de Receptor An No Def. Para '/
      DATA ERRCOD(68)/'260'/,
     &  ERRMSG(68)/'Nmero de Factores de Emisin Excede Mx:   NQF = '/
      DATA ERRCOD(69)/'270'/,
     &  ERRMSG(69)/'Nmero de Altos Valores Excede Mx:        NVAL = '/
      DATA ERRCOD(70)/'280'/,
     &  ERRMSG(70)/'Nmero de Mximos Valores Excede Mx:      NMAX = '/
C     Message '290' specified below as array element 120.
      DATA ERRCOD(71)/'300'/,
     &  ERRMSG(71)/'SRCID Indicada No Ha Sido Definida An:   Clave = '/
      DATA ERRCOD(72)/'310'/,
     &  ERRMSG(72)/'Intento de Definir Card LOCATION Dupl. Para SRC:  '/
      DATA ERRCOD(73)/'315'/,
     &  ERRMSG(73)/'Intento de Definir Card SCRPARAM Dupl. Para SRC:  '/
      DATA ERRCOD(74)/'320'/,
     &  ERRMSG(74)/'Parm. de Fuente Puede Estar Fuera de Rango Para  '/
      DATA ERRCOD(75)/'325'/,
     &  ERRMSG(75)/'Vel. De Salida Neg. (Se Deja En 1.0E-5) para SRCID'/
      DATA ERRCOD(76)/'330'/,
     &  ERRMSG(76)/'Los Parms de Fraccin de Masa No Suman 1 Para SRC'/
      DATA ERRCOD(77)/'332'/,
     &  ERRMSG(77)/'Parm de Fraccin de Masa Fuera de Rango Para     '/
      DATA ERRCOD(78)/'334'/,
     &  ERRMSG(78)/'Densidad de Partcula Fuera de Rango Para Fuente  '/
      DATA ERRCOD(79)/'340'/,
     &  ERRMSG(79)/'Posible Error En ANHT de ANEMHGHT. El Valor Es    '/
      DATA ERRCOD(80)/'350'/,
     &  ERRMSG(80)/'Da Juliano Fuera de Rango en                     '/
      DATA ERRCOD(81)/'360'/,
     &  ERRMSG(81)/'Ao Indicado en 2 Dgitos: Rango Vlido 1901-2099 '/
      DATA ERRCOD(82)/'370'/,
     &  ERRMSG(82)/'Fecha Invlida: 2/29 En Ao No Bisiesto           '/
      DATA ERRCOD(83)/'380'/,
     &  ERRMSG(83)/'Esta Variable de Entrada Est Fuera de Rango      '/
      DATA ERRCOD(84)/'385'/,
     &  ERRMSG(84)/'Perodo de Promediacin .NE. 1-Hr para TOXXFILE Op'/
      DATA ERRCOD(85)/'400'/,
     &  ERRMSG(85)/'No Hay Convergencia en SUB. CUBIC.     KURDAT=    '/
      DATA ERRCOD(86)/'410'/,
     &  ERRMSG(86)/'Vector de Flujo Furea de Rango.   KURDAT=         '/
      DATA ERRCOD(87)/'420'/,
     &  ERRMSG(87)/'Velocidad Elica Fuera de Rango.   KURDAT=        '/
      DATA ERRCOD(88)/'430'/,
     &  ERRMSG(88)/'Datos de Temp. Ambiente Fuera de Rango.  KURDAT=  '/
      DATA ERRCOD(89)/'440'/,
     &  ERRMSG(89)/'Hora de Calma Identificada en Datos Meteor. a     '/
      DATA ERRCOD(90)/'450'/,
     &  ERRMSG(90)/'Error en Archivo Meteor. Regist. Fuera de Secu. en'/
      DATA ERRCOD(91)/'460'/,
     &  ERRMSG(91)/'Faltante de Hora en Archivo Metorolgico en       '/
      DATA ERRCOD(92)/'470'/,
     &  ERRMSG(92)/'Valor de Altura de Mezclado es <= 0.0.   KURDAT=  '/
      DATA ERRCOD(93)/'500'/,
     &  ERRMSG(93)/'Error Fatal Ocurre Al Abrir Archivo de Datos      '/
      DATA ERRCOD(94)/'510'/,
     &  ERRMSG(94)/'Error Fatal Ocurre Al Leer Archivo                '/
      DATA ERRCOD(95)/'520'/,
     &  ERRMSG(95)/'Error Fatal Ocurre Al Escribir en el Archivo      '/
      DATA ERRCOD(96)/'530'/,
     &  ERRMSG(96)/'Error Al Leer Estacin Meteor. o Ao: Archivo dice'/
      DATA ERRCOD(97)/'540'/,
     &  ERRMSG(97)/'No RECTABLE/MAXTABLE/DAYTABLE Para Perodo de Prom'/
      DATA ERRCOD(98)/'550'/,
     &  ERRMSG(98)/'Conflicto El Nombre Del Archivo En La Opcin:     '/
      DATA ERRCOD(99)/'560'/,
     &  ERRMSG(99)/'Usuario Indica Unidad de Archivo < 20 Para Clave: '/
      DATA ERRCOD(100)/'565'/,
     & ERRMSG(100)/'Posible Conflicto Con La Dinmicamente Asig. FUNIT'/
      DATA ERRCOD(101)/'570'/,
     & ERRMSG(101)/'Problema Al Leer Archivo Temporal de Eventos Para '/
      DATA ERRCOD(102)/'580'/,
     & ERRMSG(102)/'Se Lleg a Fin de Archivo Tratando de Leer Archivo'/
      DATA ERRCOD(103)/'305'/,
     & ERRMSG(103)/'Cuadric de Terreno No Cubre Area Modelada, Cambiar'/
      DATA ERRCOD(104)/'144'/,
     & ERRMSG(104)/'Opciones En Conflico: NOSMPL con Terreno FLAT     '/
      DATA ERRCOD(105)/'151'/,
     & ERRMSG(105)/'CO ELEVUNIT card caduco: use card RE ELEVUNIT     '/
      DATA ERRCOD(106)/'152'/,
     & ERRMSG(106)/'ELEVUNIT card must be first for this Pathway:     '/
      DATA ERRCOD(107)/'153'/,
     & ERRMSG(107)/'No Puede Usar card CO ELEVUNIT con ELEVUNIT para  '/
      DATA ERRCOD(108)/'391'/,
     & ERRMSG(108)/'Tasa de Aspecto (L/W) de Fuente de Area mayor a 10'/
      DATA ERRCOD(109)/'392'/,
     & ERRMSG(109)/'Tasa de Aspecto (L/W) de Fosa Abierta es > 10     '/
      DATA ERRCOD(110)/'393'/,
     & ERRMSG(110)/'Cuadric de Terr Difiere > 50% De La Elev de Fuente'/
      DATA ERRCOD(111)/'394'/,
     & ERRMSG(111)/'Cuadric de Terr Difiere > 50% De La Elev de Recept'/
      DATA ERRCOD(112)/'322'/,
     & ERRMSG(112)/'Altura de Liber Excede Profund Efect para OPENPIT '/
      DATA ERRCOD(113)/'243'/,
     & ERRMSG(113)/'Coef de Elimin Puede Estar Fuera de Rango En SRCID'/
C     Message 143 modified with version dated 00101. RWB
      DATA ERRCOD(114)/'143'/,
     & ERRMSG(114)/'Opcin UNFORM no soportada. Convertir datos utiliz'/
      DATA ERRCOD(115)/'435'/,
     & ERRMSG(115)/'Long. de Aspereza Superf Fuera de Rango.  KURDAT= '/


      DATA ERRCOD(116)/'342'/,
     & ERRMSG(116)/'ID Incongr en Archivo de Emision Por Hora Para ID='/
      DATA ERRCOD(117)/'344'/,
     & ERRMSG(117)/'Tasa de Emisin Por Hora Es Cero para KURDAT =    '/
C*----
C*#

      DATA ERRCOD(118)/'157'/,
     & ERRMSG(118)/'Clave EMISUNIT Se Usa Con Ms de 1 Tipo de Result '/
      DATA ERRCOD(119)/'158'/,
     & ERRMSG(119)/'Clave EMISUNIT Se Usa Con La Siguiente Clave:     '/
      DATA ERRCOD(120)/'290'/,
     & ERRMSG(120)/'Nmero de Tipos de Result Excede Mx: NTYP =      '/
      DATA ERRCOD(121)/'295'/,
     & ERRMSG(121)/'Promedios PERIOD and ANNUAL Se Selec a la Vez Para'/
      DATA ERRCOD(122)/'455'/,
     & ERRMSG(122)/'Fecha/Tiempo Incongr: Arch de Emisi/Hora. KURDAT= '/
      DATA ERRCOD(123)/'323'/,
     & ERRMSG(123)/'No Se Especifican Categ de Partic Para OPENPIT    '/
      DATA ERRCOD(124)/'197'/,
     & ERRMSG(124)/'Post-97 PM10 sin MAXIFILE es incompatible con     '/
      DATA ERRCOD(125)/'298'/,
     & ERRMSG(125)/'Error Asignando Almacenaje para Estab de Matrices!'/
      DATA ERRCOD(126)/'299'/,
     & ERRMSG(126)/'Error Asignando Almacenaje para Matrices Result!  '/

      DATA ERRCOD(127)/'262'/,
     & ERRMSG(127)/'Primer Vrt no concuerda LOCATION para AREAPOLY   '/
      DATA ERRCOD(128)/'264'/,
     & ERRMSG(128)/'Demasiados Vrt especificados para fuente AREAPOLY'/
      DATA ERRCOD(129)/'265'/,
     & ERRMSG(129)/'Insuficientes Vrt especific para fuente AREAPOLY '/

C     Add error/warning messages associated with post-1997 PM10 processing
      DATA ERRCOD(130)/'352'/,
     & ERRMSG(130)/'Campo faltante tarjeta MULTYEAR para Pre-1997 PM10'/
      DATA ERRCOD(131)/'353'/,
     & ERRMSG(131)/'Clave MULTYEAR para procesamiento PM10 aplica slo'/
      DATA ERRCOD(132)/'354'/,
     & ERRMSG(132)/'High-4th-High requerida slo para Post-1997 PM10  '/
      DATA ERRCOD(133)/'363'/,
     & ERRMSG(133)/'Promedios 24-Hr y ANNUAL slo para Post-1997 PM10 '/
      DATA ERRCOD(134)/'480'/,
     & ERRMSG(134)/'Menos de 1 ao encontrado para promedios ANNUAL   '/
      DATA ERRCOD(135)/'485'/,
     & ERRMSG(135)/'Datos remanentes despus Fin de Ao. Nm de horas='/

      DATA ERRCOD(136)/'487'/,
     & ERRMSG(136)/'Fecha de inicio es anterior del archivo de inicio '/
      DATA ERRCOD(137)/'319'/,
     & ERRMSG(137)/'No se incluyen fuentes en el grupo de fuente espec'/
      DATA ERRCOD(138)/'313'/,
     & ERRMSG(138)/'Intento de definir la tarjeta EVENTPER duplicada  '/
      DATA ERRCOD(139)/'413'/,
     & ERRMSG(139)/'Nm de eventos umbral > 9999 para periodo promedio'/
      DATA ERRCOD(140)/'405'/,
     & ERRMSG(140)/'Aumentar NVMAX para fuentes AREAPOLY complejas    '/

      DATA ERRCOD(141)/'196'/,
     & ERRMSG(141)/'Palabra clave incompatible utilizada con GASDEPVD '/
      DATA ERRCOD(142)/'154'/,
     & ERRMSG(142)/'Opciones contrarias:  SCIM no puede ser util con  '/
      DATA ERRCOD(143)/'156'/,
     & ERRMSG(143)/'Opcin ignorada - no vlida con SCIM.  Opcin =   '/
      DATA ERRCOD(144)/'198'/,
     & ERRMSG(144)/'Opcin TOXICS requerida con de utilizar la opcin '/

C     Add error message for year exceeding 2147.
      DATA ERRCOD(145)/'365'/,
     & ERRMSG(145)/'El ao de entrada es mayor a 2147                 '/

C     Add error messages for HE > ZI issue.
      DATA ERRCOD(146)/'282'/,
     & ERRMSG(146)/'RecElev < SrcBase; Vea non-DFAULT HE>ZI opcin en '/
      DATA ERRCOD(147)/'283'/,
     & ERRMSG(147)/'HE > ZI para el fuents y receptor:                '/

      END MODULE MAIN1


      MODULE DEPVAR
c-----------------------------------------------------------------------
c --- ISCST2    Version: 1.0            Level: 931215        DEPVAR
c               D. Strimaitis, SRC
c
c PURPOSE:     Include-file of parameters and commons for deposition
c
c MODIFIED:    Split terrain grid common blocks to avoid alignment warning.
c              R. Brode, PES, Inc. - 5/24/95
c
c MODIFIED:    Added variable kurdat to common.
c              R. Brode, PES, Inc. - 9/30/94
c
c-----------------------------------------------------------------------
C     The following commented line provides the array limits for the
C     Microsoft executable file.

      IMPLICIT NONE

c-----------------------------------------------------------------------
c --- PARAMETERS
c-----------------------------------------------------------------------
      REAL, PARAMETER :: rtpiby2 = 1.2533141, rt2 = 1.4142136,
     &                   rtpi = 1.7724539

c-----------------------------------------------------------------------
c --- COMMON BLOCK /DEPVAR/ --- Source Depletion Variables
c-----------------------------------------------------------------------
      LOGICAL   :: rural, urban, lterr, debug, ltoxics
      CHARACTER :: srctyp*8
      REAL ::      vd, vs, zd, ap, bp, cp, ar, br, cr,
     &             hmix, onebyu,
     &             er, ep, xsrc, ysrc, xrec, yrec,
     &             xr, xv, h, sgz, sgz0, xtd, sztd, szmn
      INTEGER ::   igrav, kst, iounit, kurdat

c-----------------------------------------------------------------------
c --- COMMON BLOCK /TGRID/ --- Gridded Terrain Variables
c-----------------------------------------------------------------------
      LOGICAL ltgrid
      INTEGER (KIND=2), ALLOCATABLE :: izarray(:,:)
      REAL ::         xllm, yllm, sizem, xurm, yurm
      INTEGER ::      ntx, nty

c-----------------------------------------------------------------------
c     DEFINITIONS       [i]=integer     [r]=real       [l]=logical
c-----------------------------------------------------------------------
c                      - PARAMETERS -
c rtpiby2        square root of pi/2                                 [r]
c rt2            square root of 2                                    [r]
c rtpi           square root of pi                                   [r]
c (note: mxtx and mxty now allocated at runtime)
c
c                         /DEPVAR/
c vd (m/s)       deposition velocity                                 [r]
c vs (m/s)       gravitational settling velocity                     [r]
c zd (m)         reference height for deposition calculation         [r]
c ap,bp,cp       coefficients for analytical form of profile fcn     [r]
c ar,br,cr       coefficients for resistance function                [r]
c igrav          flag for treatment of gravitational settling        [i]
c                  0:use analytical approximation to profile integral
c                  1:use numerical solution to profile integral
c rural,urban    logical indicators for dispersion site character    [l]
c kst            P-G stability class                                 [i]
c hmix (m)       mixing height                                       [r]
c onebyu (s/m)   reciprocal of wind speed                            [r]
c er (m)         elevation (MSL) of receptor location                [r]
c ep (m)         elevation (MSL) of point-source location            [r]
c (x,y)src (m)   source location                                     [r]
c (x,y)rec (m)   receptor location                                   [r]
c xr (m)         distance from source to receptor                    [r]
c xv (m)         virtual source distance upwind of actual source     [r]
c h (m)          plume centerline height (no gravitational settling) [r]
c sgz (m)        sigma-z                                             [r]
c sgz0 (m)       initial sigma-z (e.g. for BID)                      [r]
c xtd (m)        distance to centerline "touchdown" (settling)       [r]
c sgtd (m)       sigma-z at xtd                                      [r]
c szmn (m)       minimum allowed for "settling" sigma-z              [r]
c lterr          logical controlling terrain adjustments             [l]
c debug          logical indicator for debug option                  [l]
c iounit         unit number for debug output                        [i]
c srctyp         source type (8 characters)                          [c]
c
c                         /TGRID/
c (x,y)llm   (m) coordinates of SW corner of cell1 (lower left
c                  corner) of terrain grid                           [r]
c sizem      (m) length of side of terrain grid cell                 [r]
c (x,y)urm   (m) coordinates of upper right corner of terrain grid   [r]
c izarray (m MSL) gridded terrain elevation data                     [i]
c
c  NOTE:  This grid contains terrain elevations at the corner of each
c         cell.  Therefore there are nx+1 points in x, and ny+1 points
c         in y.  The coordinates are assumed to be referenced to the
c         same origin used to specify source and receptor locations.
c-----------------------------------------------------------------------

      END MODULE DEPVAR
